@@ -131,7 +131,13 @@ QSet<QString> ProcessInfo::commonDirNames()
     if (forTheFirstTime) {
         const KSharedConfigPtr &config = KSharedConfig::openConfig();
         const KConfigGroup &configGroup = config->group("ProcessInfo");
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+        // Need to make a local copy so the begin() and end() point to the same QList
+        const QStringList commonDirsList = configGroup.readEntry("CommonDirNames", QStringList());
+        _commonDirNames = QSet<QString>(commonDirsList.begin(), commonDirsList.end());
+#else
         _commonDirNames = QSet<QString>::fromList(configGroup.readEntry("CommonDirNames", QStringList()));
+#endif
 
         forTheFirstTime = false;
     }
@@ -422,7 +428,7 @@ void UnixProcessInfo::readUserName()
 class LinuxProcessInfo : public UnixProcessInfo
 {
 public:
-    LinuxProcessInfo(int pid) :
+    explicit LinuxProcessInfo(int pid) :
         UnixProcessInfo(pid)
     {
     }
@@ -475,7 +481,11 @@ private:
                 }
             } while (!statusLine.isNull() && uidLine.isNull());
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
+            uidStrings << uidLine.split(QLatin1Char('\t'), Qt::SkipEmptyParts);
+#else
             uidStrings << uidLine.split(QLatin1Char('\t'), QString::SkipEmptyParts);
+#endif
             // Must be 5 entries: 'Uid: %d %d %d %d' and
             // uid string must be less than 5 chars (uint)
             if (uidStrings.size() == 5) {
@@ -599,7 +609,7 @@ private:
 class FreeBSDProcessInfo : public UnixProcessInfo
 {
 public:
-    FreeBSDProcessInfo(int pid) :
+    explicit FreeBSDProcessInfo(int pid) :
         UnixProcessInfo(pid)
     {
     }
@@ -724,7 +734,7 @@ private:
 class OpenBSDProcessInfo : public UnixProcessInfo
 {
 public:
-    OpenBSDProcessInfo(int pid) :
+    explicit OpenBSDProcessInfo(int pid) :
         UnixProcessInfo(pid)
     {
     }
@@ -842,7 +852,7 @@ private:
 class MacProcessInfo : public UnixProcessInfo
 {
 public:
-    MacProcessInfo(int pid) :
+    explicit MacProcessInfo(int pid) :
         UnixProcessInfo(pid)
     {
     }
@@ -923,7 +933,7 @@ private:
 
     bool readArguments(int pid) override
     {
-        Q_UNUSED(pid);
+        Q_UNUSED(pid)
         return false;
     }
 };
@@ -943,7 +953,7 @@ private:
 class SolarisProcessInfo : public UnixProcessInfo
 {
 public:
-    SolarisProcessInfo(int pid) :
+    explicit SolarisProcessInfo(int pid) :
         UnixProcessInfo(pid)
     {
     }
